<?php

	/**
	* Woopra module for Interspire Shopping Cart. To enable
	* this module in Interspire Shopping Cart login to the control panel and click the
	* Settings -> Analytics Settings tab in the menu.
	*
	* Created [Feb 17th 2011]
	* - Uses Asynchonous JS handling for speed
	* - Product tracking properly handled
	* - New admin field (no sanity checking) for UA code input
	*/
	class ANALYTICS_WOOPRA extends ISC_ANALYTICS
	{

		/*
			Analytics class constructor
		*/
		public function __construct()
		{

			// Setup the required variables for the Google analytics module
			parent::__construct();

			$this->_name = GetLang('WoopraName');
			$this->_image = "woopra_badge_160px.jpg";
			$this->_description = GetLang('WoopraDesc');
			$this->_help = GetLang('WoopraHelp');
			$this->_height = 0;
		}

		/**
		* Custom variables for the analytics module. Custom variables are stored in the following format:
		* array(variable_id, variable_name, variable_type, help_text, default_value, required, [variable_options], [multi_select], [multi_select_height])
		* variable_type types are: text,number,password,radio,dropdown
		* variable_options is used when the variable type is radio or dropdown and is a name/value array.
		*/
		public function SetCustomVars()
		{

			$this->_variables['trackingcode'] = array(
				"name" => "Tracking Code",
				"type" => "textarea",
				"help" => GetLang('WoopraCodeHelp'),
				"default" => "",
				"required" => true,
				"rows" => 7
			);
		}

		/**
		* Return the tracking code for this analytics module.
		*/

		public function GetTrackingCode()
		{
			/*
			 * Returns no tracking code when the conversion code will fire anyway.
			 * Avoids duplicate data hitting Woopra simultaneously.
			 */
			if(strpos($_SERVER['PHP_SELF'], "finishorder.php")) {
				return '';
			}
			
			$trackingCode = '';
			
			if(!empty($GLOBALS['CurrentCustomerFirstName']) || !empty($GLOBALS['CurrentCustomerLastName'])) {
				$trackingCode = "
<script type=\"text/javascript\">
var woo_visitor={name:'{$GLOBALS['CurrentCustomerFirstName']} {$GLOBALS['CurrentCustomerLastName']}'};
</script>
";
			}
			
			$trackingCode .= $this->GetValue("trackingcode");

			if(GetConfig('FacebookLikeButtonEnabled')) {
				$trackingCode .= "
				
<!-- Start: Tracking Facebook Like with Woopra -->
<script type=\"text/javascript\">
$(function(){
	if (typeof FB != 'undefined') {
    	FB.Event.subscribe('edge.create', function(url) {
	        woopraTracker.pushEvent({name: 'Facebook Like', url: url});
    	});
	}
});
</script>
<!-- End: Tracking Facebook Like with Woopra -->

";
			}

			return $trackingCode;
		}

        /**
         * Return the conversion tracking code for this module.
         */
        public function GetConversionCode()
        {

            // Grab the first order ID from the stack and we'll use that
            $orders = $this->GetOrders();
            $order = current($orders);
            $orderId = $order['orderid'];
            $billingAddress = $this->GetBillingDetails();

			$conversionCode = "
<script type=\"text/javascript\">
var woo_visitor={name:'{$billingAddress['ordbillfirstname']} {$billingAddress['ordbilllastname']}', email:'{$billingAddress['ordbillemail']}', orderID: '{$orderId}'};
</script>
";
			$conversionCode .= $this->GetValue("trackingcode");
            return $conversionCode;
        } 
	}